<?php
/*
  Plugin Name: DeMomentSomTres WordPress Plugin Custom Post Type
  Plugin URI: http://demomentsomtres.com/english/wordpress-plugins/demomentsomtres-wordpress-plugins/
  Description: Provides a post type specific for wordpress plugins and integrates it with plugin info
  Version: 1.1
  Author: Marc Queralt
  Author URI: http://demomentsomtres.com
  License: GPL2
 */

class DeMomentSomTres_WordPress_Plugin {

    /**
     * Post type slug to use for storing plugin information from the repo
     *
     * @access public
     * @var string
     */
    var $post_type = 'dms3-wp-plugin';

    public function __construct() {
        add_action('init', array($this, 'create_content_type'));
        add_action('admin_menu', array($this, 'action_admin_menu'));
        add_shortcode('DeMomentSomTres-Plugins', array($this, 'shortcode_plugins'));
    }

    public function create_content_type() {
        register_post_type($this->post_type, array(
            'labels' => array(
                'name' => 'WordPress Plugins',
                'singular_name' => 'WordPress Plugin',
                'all_items' => 'All of Plugins',
                'add_new_item' => 'Add a Plugin',
                'edit_item' => 'Edit a Plugin',
                'view_item' => 'View My Plugins',
                'new_item' => 'New Plugin',
                'search_items' => 'Search Plugins',
                'not_found' => 'No Plugins found',
                'not_found_in_trash' => 'No Plugins found in trash',
            ),
            'description' => 'Custom post for WordPress plugins',
            'public' => true,
            'hierarchical' => false,
            'supports' => array(
                'title',
                'editor',
                'author',
                'thumbnail',
                'page-attributes',
                'comments',
            ),
            'has_archive' => true,
            'rewrite' => array(
                'slug' => 'wordpress-plugins',
                'with_front' => false,
            ),
            'yarpp_support' => true,
            'taxonomies' => array('post_tag',),
                )
        );
    }

    public function meta_box($post) {
        ?>
        <label for="plugin_info"><?php _e('Plugin slug:', 'plugin_info'); ?></label>
        <input type="text" name="plugin_info" id="plugin_info" value="<?php esc_attr_e(get_post_meta($post->ID, 'plugin', true)); ?>" />
        <p class="howto"><?php _e('To display information about a plugin, you should use one of the shortcodes below.', 'plugin_info'); ?></p>
        <div id="plugin_info_shortcodes">
            <p><?php _e('Plain info:', 'plugin_info'); ?></p>
            <dl>
                <dt>[plugin author_name]</dt>
                <dd class="howto"><?php _e('Author&rsquo;s name', 'plugin_info'); ?></dd>
                <dt>[plugin author_url]</dt>
                <dd class="howto"><?php _e('Author&rsquo;s URL', 'plugin_info'); ?></dd>
                <dt>[plugin compatibility]</dt>
                <dd class="howto"><?php _e('Concensus on compatibility with latest WP version (% of people who say it works)', 'plugin_info'); ?></dd>
                <dt>[plugin compat_with]</dt>
                <dd class="howto"><?php _e('Version of WordPress used for the compatibility concensus', 'plugin_info'); ?></dd>
                <dt>[plugin download_url]</dt>
                <dd class="howto"><?php _e('URL of ZIP file', 'plugin_info'); ?></dd>
                <dt>[plugin downloaded]</dt>
                <dd class="howto"><?php _e('Download count', 'plugin_info'); ?></dd>
                <dt>[plugin homepage_url]</dt>
                <dd class="howto"><?php _e('URL of homepage', 'plugin_info'); ?></dd>
                <dt>[plugin donate_url]</dt>
                <dd class="howto"><?php _e('URL of donations page', 'plugin_info'); ?></dd>
                <dt>[plugin link_url]</dt>
                <dd class="howto"><?php _e('URL of wp.org page', 'plugin_info'); ?></dd>
                <dt>[plugin name]</dt>
                <dd class="howto"><?php _e('Name', 'plugin_info'); ?></dd>
                <dt>[plugin profile_url]</dt>
                <dd class="howto"><?php _e('URL of author&rsquo;s wp.org profile', 'plugin_info'); ?></dd>
                <dt>[plugin requires]</dt>
                <dd class="howto"><?php _e('&rsquo;Requires at least&lsquo; version number', 'plugin_info'); ?></dd>
                <dt>[plugin rating]</dt>
                <dd class="howto"><?php _e('Rating out of 5', 'plugin_info'); ?></dd>
                <dt>[plugin slug]</dt>
                <dd class="howto"><?php _e('Slug', 'plugin_info'); ?></dd>
                <dt>[plugin tags]</dt>
                <dd class="howto"><?php _e('List of tags', 'plugin_info'); ?></dd>
                <dt>[plugin tested]</dt>
                <dd class="howto"><?php _e('&rsquo;Tested up to&lsquo; version number', 'plugin_info'); ?></dd>
                <dt>[plugin updated_ago]</dt>
                <dd class="howto"><?php _e('Last updated ago (hours/days/weeks)', 'plugin_info'); ?></dd>
                <dt>[plugin updated]</dt>
                <dd class="howto"><?php _e('Last updated date', 'plugin_info'); ?></dd>
                <dt>[plugin version]</dt>
                <dd class="howto"><?php _e('Version number', 'plugin_info'); ?></dd>
            </dl>
            <p><?php _e('Formatted info:', 'plugin_info'); ?></p>
            <dl>
                <dt>[plugin author]</dt>
                <dd class="howto"><?php _e('Link to author&rsquo;s homepage', 'plugin_info'); ?></dd>
                <dt>[plugin contributors]</dt>
                <dd class="howto"><?php _e('List of contributors', 'plugin_info'); ?></dd>
                <dt>[plugin description]</dt>
                <dd class="howto"><?php _e('Long description', 'plugin_info'); ?></dd>
                <dt>[plugin installation]</dt>
                <dd class="howto"><?php _e('Installation directions', 'plugin_info'); ?></dd>
                <dt>[plugin faq]</dt>
                <dd class="howto"><?php _e('List of FAQs', 'plugin_info'); ?></dd>
                <dt>[plugin download]</dt>
                <dd class="howto"><?php _e('Link to ZIP file', 'plugin_info'); ?></dd>
                <dt>[plugin homepage]</dt>
                <dd class="howto"><?php _e('Link to homepage', 'plugin_info'); ?></dd>
                <dt>[plugin donate]</dt>
                <dd class="howto"><?php _e('Link to donations page', 'plugin_info'); ?></dd>
                <dt>[plugin link]</dt>
                <dd class="howto"><?php _e('Link to wp.org page', 'plugin_info'); ?></dd>
                <dt>[plugin profile]</dt>
                <dd class="howto"><?php _e('Link to author&rsquo;s wp.org profile', 'plugin_info'); ?></dd>
                <dt>[plugin screenshots]</dt>
                <dd class="howto"><?php _e('List of screenshots', 'plugin_info'); ?></dd>
                <dt>[plugin changelog]</dt>
                <dd class="howto"><?php _e('List of changelog entries', 'plugin_info'); ?></dd>
                <dt>[plugin latest_change]</dt>
                <dd class="howto"><?php _e('Latest changelog entry', 'plugin_info'); ?></dd>
                <dt>[plugin other_notes]</dt>
                <dd class="howto"><?php _e('Other notes', 'plugin_info'); ?></dd>
            </dl>
        </div>
        <p><a href="#" id="plugin_info_show_shortcodes"><?php _e('[ show ]', 'plugin_info'); ?></a></p>
        <?php
    }

    public function action_admin_menu() {
        add_meta_box(
                'plugininfo', __('Plugin Info', 'plugin_info'), array($this, 'meta_box'), $this->post_type, 'side'
        );
    }

    public function shortcode_plugins($atts) {
        $html = '';
        extract(shortcode_atts(array(
            'cols' => 4,
            'tag' => 'h2',
                        ), $atts));
        $byrow = (int) (12 / $cols);
        // in a new row
        $plugins = $this->get_plugins();
        $html.='<div class="demomentsomtres-wordpress-plugins">';
        $i = 0;
        $r = 0;
        foreach ($plugins as $p):
            if (0 == $i % $byrow):
                $html .= "<ul class='row-fluid thumbnails row$r'>";
            endif;
            $url = get_permalink($p->ID);
            $img = $this->featuredImage($p);
            $html .= "<li class='span$cols'>"
                    . "<a class='thumbnail' href='$url'>"
                    . $img
                    . "<span class='caption'>$p->post_title</span>"
                    . "</a>"
                    . "</li>";
            if ($byrow - 1 == $i % $byrow):
                // end of row
                $html .= '</ul>';
            endif;
            $i++;
            $r = $r % 2;
        endforeach;
        if (0 != ($i) % $byrow):
            // was not ended
            $html .= '</ul>';
        endif;
        $html .= '</div>';
        return $html;
    }

    function get_plugins() {
        $q = new WP_Query(
                array(
            'post_type' => $this->post_type,
            'showposts' => -1,
            'orderby' => 'menu_order'
                )
        );
        return $q->posts;
    }

    function featuredImage($post) {
        $html = '';
        $size = 'medium';
        if (has_post_thumbnail($post->ID)):
            $html.=get_the_post_thumbnail($post->ID, $size, array(
                'class' => 'thumb',
                'alt' => $post->post_title,
                'style' => "width:100%",
            ));
        else:
            $html.="<img class='thumb empty' src='' />";
        endif;
        return $html;
    }

}

new DeMomentSomTres_WordPress_Plugin();
